@@ -609,3 +609,7 @@ def test_NRTL_one_component():
     for s in GE._point_properties:
         if hasattr(GE, s):
             res = getattr(GE, s)()
+
+def test_NRTL_can_return_zero_may_need_lngamma_call():
+    obj = NRTL(T=8, xs=[0.999999, 2.5e-07, 2.5e-07, 2.5e-07, 2.5e-07], tau_as=[[0, -5.1549, 0, 0, 0], [5.8547, 0, -0.40926, 0, 0], [0, -0.39036, 0, 0, 0], [0, 0, 0, 0, 0], [0, 0, 0, 0, 0]], tau_bs=[[0, 2270.62, 284.966, 0, 0], [229.497, 0, 1479.46, 0, 0], [-216.256, 447.003, 0, 0, 0], [0, 0, 0, 0, 0], [0, 0, 0, 0, 0]], alpha_cs=[[0, 0.2, 0.3, 0, 0], [0.2, 0, 0.46, 0, 0], [0.3, 0.46, 0, 0, 0], [0, 0, 0, 0, 0], [0, 0, 0, 0, 0]])
+    assert obj.gammas()[2] == 0
\ No newline at end of file
