@@ -572,6 +572,11 @@ class Bulk(Phase):
         tot_inv = 1.0/tot
         return [betas[i]*MWs_phases[i]*tot_inv for i in phase_iter]
 
+    @property
+    def beta_mass(self):
+        return sum(self.betas_mass)
+
+
     @property
     def betas_volume(self):
         r'''Method to calculate and return the volume fraction of all of the
@@ -596,6 +601,10 @@ class Bulk(Phase):
         tot_inv = 1.0/tot
         return [betas[i]*Vs_phases[i]*tot_inv for i in phase_iter]
 
+    @property
+    def beta_volume(self):
+        return sum(self.betas_volume)
+
     def _property_mixing_rule(self, method, exponent, mix_obj, attr):
         if method == AS_ONE_LIQUID:
             prop = mix_obj.mixture_property(self.T, self.P, self.zs, self.ws())
