@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 r'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
-Copyright (C) 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+Copyright (C) 2020, 2021 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -69,16 +69,47 @@ implemented
 from fluids.constants import R
 from fluids.numerics import numpy as np, catanh
 from math import sqrt, log
-from thermo.eos_volume import volume_solutions_halley
+from thermo.eos import eos_lnphi
+from thermo.eos_volume import volume_solutions_halley, volume_solutions_fast
 
 __all__ = ['a_alpha_aijs_composition_independent',
            'a_alpha_and_derivatives', 'a_alpha_and_derivatives_full',
            'a_alpha_quadratic_terms', 'a_alpha_and_derivatives_quadratic_terms',
-           'PR_lnphis', 'VDW_lnphis',
-           'PR_lnphis_fastest', 'lnphis_direct',
-           'G_dep_lnphi_d_helper', 'PR_translated_ddelta_dzs',
-           'PR_translated_depsilon_dzs',
-           'eos_mix_dV_dzs']
+           'PR_lnphis', 'VDW_lnphis', 'SRK_lnphis', 'eos_mix_lnphis_general',
+           
+           'VDW_lnphis_fastest', 'PR_lnphis_fastest',
+           'SRK_lnphis_fastest', 'RK_lnphis_fastest',
+           'PR_translated_lnphis_fastest',
+           
+           'G_dep_lnphi_d_helper', 
+           
+           'RK_d3delta_dninjnks',
+           'PR_ddelta_dzs', 'PR_ddelta_dns',
+           'PR_d2delta_dninjs', 'PR_d3delta_dninjnks',
+           
+           'PR_depsilon_dns', 'PR_d2epsilon_dninjs', 'PR_d3epsilon_dninjnks',
+           'PR_d2epsilon_dzizjs', 'PR_depsilon_dzs',
+           
+           'PR_translated_d2delta_dninjs', 'PR_translated_d3delta_dninjnks', 
+           'PR_translated_d3epsilon_dninjnks',
+           
+           'PR_translated_ddelta_dzs', 'PR_translated_ddelta_dns',           
+           'PR_translated_depsilon_dzs', 'PR_translated_depsilon_dns',
+           'PR_translated_d2epsilon_dzizjs', 'PR_translated_d2epsilon_dninjs',
+           
+           'SRK_translated_ddelta_dns', 'SRK_translated_depsilon_dns',
+           'SRK_translated_d2epsilon_dzizjs', 'SRK_translated_depsilon_dzs',
+           'SRK_translated_d2delta_dninjs', 
+           'SRK_translated_d3delta_dninjnks',
+           'SRK_translated_d2epsilon_dninjs', 'SRK_translated_d3epsilon_dninjnks',
+
+           
+           'SRK_translated_lnphis_fastest',
+           
+           
+           'eos_mix_db_dns', 'eos_mix_da_alpha_dns',
+           
+           'eos_mix_dV_dzs', 'eos_mix_a_alpha_volume']
 
 
 R2 = R*R
@@ -408,7 +439,8 @@ def a_alpha_and_derivatives_full(a_alphas, da_alpha_dTs, d2a_alpha_dT2s, T, zs,
     return a_alpha, da_alpha_dT, d2a_alpha_dT2, a_alpha_ijs, da_alpha_dT_ijs, d2a_alpha_dT2_ijs
 
 
-def a_alpha_quadratic_terms(a_alphas, a_alpha_roots, T, zs, kijs):
+def a_alpha_quadratic_terms(a_alphas, a_alpha_roots, T, zs, kijs, 
+                            a_alpha_j_rows=None, vec0=None):
     r'''Calculates the `a_alpha` term for an equation of state along with the
     vector quantities needed to compute the fugacities of the mixture. This
     routine is efficient in both numba and PyPy.
@@ -436,6 +468,13 @@ def a_alpha_quadratic_terms(a_alphas, a_alpha_roots, T, zs, kijs):
         Mole fractions of each species
     kijs : list[list[float]]
         Constant kijs, [-]
+    a_alpha_j_rows : list[float], optional
+        EOS attractive term row destimation vector (does not need
+        to be zeroed, should be provided to prevent allocations),
+        [J^2/mol^2/Pa]
+    vec0 : list[float], optional
+        Empty vector, used in internal calculations, provide to avoid
+        the allocations; does not need to be zeroed, [-]
 
     Returns
     -------
@@ -459,32 +498,17 @@ def a_alpha_quadratic_terms(a_alphas, a_alpha_roots, T, zs, kijs):
     >>> a_alpha, a_alpha_j_rows
     (0.58562139582, [0.35469988173, 0.61604757237])
     '''
-    # This is faster in PyPy and can be made even faster optimizing a_alpha!
-#    N = len(a_alphas)
-#    a_alpha_j_rows = [0.0]*N
-#    a_alpha = 0.0
-#    for i in range(N):
-#        kijs_i = kijs[i]
-#        a_alpha_i_root_i = a_alpha_roots[i]
-#        for j in range(i):
-#            a_alpha_ijs_ij = (1. - kijs_i[j])*a_alpha_i_root_i*a_alpha_roots[j]
-#            t200 = a_alpha_ijs_ij*zs[i]
-#            a_alpha_j_rows[j] += t200
-#            a_alpha_j_rows[i] += zs[j]*a_alpha_ijs_ij
-#            t200 *= zs[j]
-#            a_alpha += t200 + t200
-#
-#        t200 = (1. - kijs_i[i])*a_alphas[i]*zs[i]
-#        a_alpha += t200*zs[i]
-#        a_alpha_j_rows[i] += t200
-#
-#    return a_alpha, a_alpha_j_rows
-
     N = len(a_alphas)
-    a_alpha_j_rows = [0.0]*N
-    things0 = [0.0]*N
+    if a_alpha_j_rows is None:
+        a_alpha_j_rows = [0.0]*N
+
     for i in range(N):
-        things0[i] = a_alpha_roots[i]*zs[i]
+        a_alpha_j_rows[i] = 0.0
+    
+    if vec0 is None:
+        vec0 = [0.0]*N
+    for i in range(N):
+        vec0[i] = a_alpha_roots[i]*zs[i]
 
     a_alpha = 0.0
     i = 0
@@ -494,8 +518,8 @@ def a_alpha_quadratic_terms(a_alphas, a_alpha_roots, T, zs, kijs):
         while j < i:
             # Numba appears to be better with this split into two loops.
             # PyPy has 1.5x speed reduction when so.
-            a_alpha_j_rows[j] += (1. - kijs_i[j])*things0[i]
-            a_alpha_j_rows[i] += (1. - kijs_i[j])*things0[j]
+            a_alpha_j_rows[j] += (1. - kijs_i[j])*vec0[i]
+            a_alpha_j_rows[i] += (1. - kijs_i[j])*vec0[j]
             j += 1
         i += 1
 
@@ -505,11 +529,34 @@ def a_alpha_quadratic_terms(a_alphas, a_alpha_roots, T, zs, kijs):
         a_alpha += a_alpha_j_rows[i]*zs[i]
 
     return a_alpha, a_alpha_j_rows
+    # This is faster in PyPy and can be made even faster optimizing a_alpha!
+    '''
+    N = len(a_alphas)
+    a_alpha_j_rows = [0.0]*N
+    a_alpha = 0.0
+    for i in range(N):
+        kijs_i = kijs[i]
+        a_alpha_i_root_i = a_alpha_roots[i]
+        for j in range(i):
+            a_alpha_ijs_ij = (1. - kijs_i[j])*a_alpha_i_root_i*a_alpha_roots[j]
+            t200 = a_alpha_ijs_ij*zs[i]
+            a_alpha_j_rows[j] += t200
+            a_alpha_j_rows[i] += zs[j]*a_alpha_ijs_ij
+            t200 *= zs[j]
+            a_alpha += t200 + t200
+
+        t200 = (1. - kijs_i[i])*a_alphas[i]*zs[i]
+        a_alpha += t200*zs[i]
+        a_alpha_j_rows[i] += t200
+
+    return a_alpha, a_alpha_j_rows
+    '''
 
 
 def a_alpha_and_derivatives_quadratic_terms(a_alphas, a_alpha_roots,
                                             da_alpha_dTs, d2a_alpha_dT2s, T,
-                                            zs, kijs):
+                                            zs, kijs, a_alpha_j_rows=None, 
+                                            da_alpha_dT_j_rows=None):
     r'''Calculates the `a_alpha` term, and its first two temperature
     derivatives, for an equation of state along with the
     vector quantities needed to compute the fugacitie and temperature
@@ -624,11 +671,10 @@ def a_alpha_and_derivatives_quadratic_terms(a_alphas, a_alpha_roots,
     N = len(a_alphas)
     a_alpha = da_alpha_dT = d2a_alpha_dT2 = 0.0
 
-#     da_alpha_dT_off = d2a_alpha_dT2_off = 0.0
-#     a_alpha_j_rows = np.zeros(N)
-    a_alpha_j_rows = [0.0]*N
-#     da_alpha_dT_j_rows = np.zeros(N)
-    da_alpha_dT_j_rows = [0.0]*N
+    if a_alpha_j_rows is None:
+        a_alpha_j_rows = [0.0]*N
+    if da_alpha_dT_j_rows is None:
+        da_alpha_dT_j_rows = [0.0]*N
 
     # If d2a_alpha_dT2s were all halved, could save one more multiply
     for i in range(N):
@@ -757,13 +803,13 @@ def G_dep_lnphi_d_helper(T, P, b, delta, epsilon, a_alpha, N,
     if x6 == 0.0:
         # VDW has x5 as zero as delta, epsilon = 0
         x6 = 1e-100
-    x7 = x6**-0.5
+    x7 = 1.0/sqrt(x6)
     x8 = a_alpha
     x9 = x0 + x0
     x10 = x4 + x9
     x11 = x2 + x2
     x12 = x11*catanh(x10*x7).real
-    x15 = 1.0/x6
+    x15 = x7*x7
 
     db_dns = dbs
     depsilon_dns = depsilons
@@ -773,7 +819,7 @@ def G_dep_lnphi_d_helper(T, P, b, delta, epsilon, a_alpha, N,
 
     t1 = P*x2
     t2 = x11*x15*x8/(x10*x10*x15 - 1.0)
-    t3 = x12*x8*x6**(-1.5)
+    t3 = x12*x8*x15*x7
     t4 = x12*x7
     t5 = 1.0/(x0 - x3)
     t6 = x4 + x9
@@ -784,16 +830,191 @@ def G_dep_lnphi_d_helper(T, P, b, delta, epsilon, a_alpha, N,
         t3 *= RT
         t4 *= RT
         t5 *= RT
-
+        
+    c0 = t1 + t2*2.0 - t5
     for i in range(N):
         x13 = ddelta_dns[i]
         x14 = x13*x4 - 2.0*depsilon_dns[i]
         x16 = x14*x15
-        x1 = dV_dns[i]
-        diff = (x1*t1 + t2*(x1 + x1 + x13 - x16*t6) + x14*t3 - t4*da_alpha_dns[i] - t5*(x1 - db_dns[i]))
+        diff = (dV_dns[i]*c0 - t4*da_alpha_dns[i] + t5*db_dns[i] 
+                + t2*(x13 - x16*t6) + x14*t3 )
+        # diff = (x1*t1 + t2*(x1 + x1 + x13 - x16*t6) + x14*t3 - t4*da_alpha_dns[i] - t5*(x1 - db_dns[i]))
         out[i] = diff
     return out
 
+def eos_mix_a_alpha_volume(gas, T, P, zs, kijs, b, delta, epsilon, a_alphas, a_alpha_roots, a_alpha_j_rows=None, vec0=None):
+    a_alpha, a_alpha_j_rows = a_alpha_quadratic_terms(a_alphas, a_alpha_roots, T, zs, kijs, a_alpha_j_rows, vec0)
+
+    V0, V1, V2 = volume_solutions_halley(T, P, b, delta, epsilon, a_alpha)
+    if not gas:
+        # Prefer liquid, ensure V0 is the smalest root
+        if V1 != 0.0:
+            if V0 > V1 and V1 > b:
+                V0 = V1
+            if V0 > V2 and V2 > b:
+                V0 = V2
+    else:
+        if V1 != 0.0:
+            if V0 < V1 and V1 > b:
+                V0 = V1
+            if V0 < V2 and V2 > b:
+                V0 = V2
+    Z = Z = P*V0/(R*T)
+    return Z, a_alpha, a_alpha_j_rows
+
+def eos_mix_db_dns(b, bs, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    for i in range(N):
+        out[i] = bs[i] - b
+    return out
+
+def eos_mix_da_alpha_dns(a_alpha, a_alpha_j_rows, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    a_alpha_n_2 = -2.0*a_alpha
+    for i in range(N):
+        out[i] = 2.0*a_alpha_j_rows[i] + a_alpha_n_2
+    return out
+
+def RK_d3delta_dninjnks(b, bs, N, out=None):
+    if out is None:
+        out = [[[0.0]*N for _ in range(N)] for _ in range(N)]# numba: delete
+        # out = np.zeros((N, N, N)) # numba: uncomment
+    m6b = -6.0*b
+    for i in range(N):
+        bi = bs[i]
+        d3b_dnjnks = out[i]
+        for j in range(N):
+            bj = bs[j]
+            r = d3b_dnjnks[j]
+            x0 = m6b + 2.0*(bi + bj)
+            for k in range(N):
+                r[k] = x0 + 2.0*bs[k]
+    return out
+
+def PR_ddelta_dzs(bs, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    for i in range(N):
+        out[i] = 2.0*bs[i]
+    return out
+
+def PR_ddelta_dns(bs, b, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    nb2 = -2.0*b
+    for i in range(N):
+        out[i] = 2.0*bs[i] + nb2
+    return out
+
+def PR_depsilon_dns(b, bs, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    b2 = b + b
+    b2b = b2*b
+    for i in range(N):
+        out[i] = b2b - b2*bs[i]
+    return out
+
+def PR_d2delta_dninjs(b, bs, N, out=None):
+    if out is None:
+        out = [[0.0]*N for _ in range(N)]# numba: delete
+        # out = np.zeros((N, N)) # numba: uncomment
+    bb = 2.0*b
+    for i in range(N):
+        bi = bs[i]
+        r = out[i]
+        x0 = 2.0*(bb - bi)
+        for j in range(N):
+            r[j] = x0 - 2.0*bs[j]
+    return out
+
+def PR_d3delta_dninjnks(b, bs, N, out=None):
+    if out is None:
+        out = [[[0.0]*N for _ in range(N)] for _ in range(N)]# numba: delete
+        # out = np.zeros((N, N, N)) # numba: uncomment
+    m3b = -3.0*b
+    for i in range(N):
+        bi = bs[i]
+        d3b_dnjnks = out[i]
+        for j in range(N):
+            bj = bs[j]
+            r = d3b_dnjnks[j]
+            x0 = 4.0*(m3b + bi + bj)
+            for k in range(N):
+                r[k] = x0 + 4.0*bs[k]
+    return out
+    
+
+def PR_d2epsilon_dzizjs(b, bs, N, out=None):
+    if out is None:
+        out = [[0.0]*N for _ in range(N)]# numba: delete
+        # out = np.zeros((N, N)) # numba: uncomment
+
+    for i in range(N):
+        l = out[i]
+        x0 = -2.0*bs[i]
+        for j in range(N):
+            l[j] = x0*bs[j]
+    return out
+
+def PR_depsilon_dzs(b, bs, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    b2n = -2.0*b
+
+    for i in range(N):
+        out[i] = b2n*bs[i]
+    return out
+
+
+
+def PR_d2epsilon_dninjs(b, bs, N, out=None):
+    if out is None:
+        out = [[0.0]*N for _ in range(N)]# numba: delete
+        # out = np.zeros((N, N)) # numba: uncomment
+
+    bb = b + b
+    b2 = b*b
+    c0 = -bb*bb - 2.0*b2
+    c1 = 2.0*(b + 0.5*bb)
+    c2 = 2.0*b + bb
+    for i in range(N):
+        l = out[i]
+        bi = bs[i]
+        x0 = c0 + c1*bi
+        x1 = c2 - 2.0*bi
+        for j in range(N):
+            l[j] = x0 + bs[j]*x1
+    return out
+
+
+def PR_d3epsilon_dninjnks(b, bs, N, out=None):
+    if out is None:
+        out = [[[0.0]*N for _ in range(N)] for _ in range(N)]# numba: delete
+        # out = np.zeros((N, N, N)) # numba: uncomment
+    
+    c0 = 24.0*b*b
+    for i in range(N):
+        bi = bs[i]
+        d3b_dnjnks = out[i]
+        c10 = -12.0*b + 4.0*bi
+        c11 = c0 -12.0*b*bi 
+        c12 = (-12.0*b + 4.0*bi)
+        
+        for j in range(N):
+            bj = bs[j]
+            x0 = c11 + bj*c12
+            x1 = c10 + 4.0*bj
+            row = d3b_dnjnks[j]
+            for k in range(N):
+                bk = bs[k]
+                term = x0 + bk*x1
+                row[k] = term
+    return out
+
+    
 
 def PR_translated_ddelta_dzs(b0s, cs, N, out=None):
     if out is None:
@@ -802,18 +1023,256 @@ def PR_translated_ddelta_dzs(b0s, cs, N, out=None):
         out[i] = 2.0*(cs[i] + b0s[i])
     return out
 
-def PR_translated_depsilon_dzs(epsilon, c, b, b0s, cs, N, out=None):
+def PR_translated_d2epsilon_dzizjs(b0s, cs, N, out=None):
+    if out is None:
+        out = [[0.0]*N for _ in range(N)] # numba: delete
+        # out = np.zeros((N, N)) # numba: uncomment
+    for j in range(N):
+        r = out[j]
+        x1 = 2.0*b0s[j]
+        x2 = 2.0*cs[j]
+        for i in range(N):
+            # Optimized
+            r[i] = x1*(cs[i] - b0s[i]) + x2*(b0s[i] + cs[i])
+    return out
+
+def PR_translated_d2epsilon_dninjs(b0s, cs, b, c, N, out=None):
+    if out is None:
+        out = [[0.0]*N for _ in range(N)] # numba: delete
+        # out = np.zeros((N, N)) # numba: uncomment
+    b0 = b + c
+    
+    v0 = -6.0*b0*b0 + 12.0*b0*c + 6.0*c*c
+    v1 = 4.0*b0 - 4.0*c
+    v2 = (-4.0*b0 - 4.0*c)
+    
+    
+    for i in range(N):
+        l = out[i]
+        b0i = b0s[i]
+        ci = cs[i]
+        x0 = v0 + b0i*v1 + ci*v2
+        x1 = v1 - 2.0*b0i + 2.0*ci
+        x2 = v2 + 2.0*b0i + 2.0*ci
+        for j in range(N):
+            l[j] = x0 + b0s[j]*x1 +  cs[j]*x2
+    return out
+
+def PR_translated_ddelta_dns(b0s, cs, delta, N, out=None):
     if out is None:
         out = [0.0]*N
-        b0 = b + c
     for i in range(N):
-        out[i] = cs[i]*(2.0*b0 + c) + c*(2.0*b0s[i] + cs[i]) - 2.0*b0*b0s[i]
+        out[i] = 2.0*(cs[i] + b0s[i]) - delta
+    return out
+
+def SRK_translated_ddelta_dns(b0s, cs, delta, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    for i in range(N):
+        out[i] = 2.0*cs[i] + b0s[i] - delta
     return out
 
 
-def PR_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_j_rows, N, out=None):
+def SRK_translated_depsilon_dns(b0s, cs, b, c, N, out=None):
     if out is None:
         out = [0.0]*N
+    b0 = b + c
+    x0 = -2.0*b0*c - 2.0*c*c
+    x1 = (b0 + 2.0*c)
+    for i in range(N):
+        out[i] = x0 + b0s[i]*c + cs[i]*x1
+    return out
+
+def SRK_translated_depsilon_dzs(b0s, cs, b, c, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    b0 = b + c
+    x0 = b0 + 2.0*c
+    for i in range(N):
+        out[i] = b0s[i]*c + cs[i]*x0
+    return out
+
+def SRK_translated_d2epsilon_dzizjs(b0s, cs, b, c, N, out=None):
+    if out is None:
+        out = [[0.0]*N for _ in range(N)] # numba: delete
+        # out = np.zeros((N, N)) # numba: uncomment
+    b0 = b + c
+    for i in range(N):
+        r = out[i]
+        x0 = 2.0*cs[i]
+        b0i = b0s[i]
+        c0i = cs[i]
+        for j in range(N):
+            r[j] = cs[j]*(x0 + b0i) + b0s[j]*c0i
+    return out
+
+
+def SRK_translated_d2delta_dninjs(b0s, cs, b, c, delta, N, out=None):
+    if out is None:
+        out = [[0.0]*N for _ in range(N)] # numba: delete
+        # out = np.zeros((N, N)) # numba: uncomment
+
+    b0 = b + c
+    c_4 = 4.0*c
+    for i in range(N):
+        t = delta - b0s[i] - cs[i]
+        r = out[i]
+        x0 = 2.0*(b0 - cs[i]) + c_4 - b0s[i]
+        for j in range(N):
+            r[j] =  x0 - b0s[j] - 2.0*cs[j]
+    return out
+
+def SRK_translated_d3delta_dninjnks(b0s, cs, b, c, delta, N, out=None):
+    if out is None:
+        out = [[[0.0]*N for _ in range(N)] for _ in range(N)] # numba: delete
+        # out = np.zeros((N, N, N)) # numba: uncomment
+
+    b0 = b + c
+    for i in range(N):
+        mat = out[i]
+        for j in range(N):
+            r = mat[j]
+            for k in range(N):
+                r[k] = (-6.0*b0 + 2.0*(b0s[i] + b0s[j] + b0s[k])
+                - 12.0*c + 4.0*(cs[i] + cs[j] + cs[k]))
+    return out
+
+def SRK_translated_d2epsilon_dninjs(b0s, cs, b, c, N, out=None):
+    if out is None:
+        out = [[0.0]*N for _ in range(N)] # numba: delete
+        # out = np.zeros((N, N)) # numba: uncomment
+    b0 = b + c
+    for i in range(N):
+        l = out[i]
+        for j in range(N):
+            v = (b0*(2.0*c - cs[i] - cs[j]) + c*(2.0*b0 - b0s[i] - b0s[j])
+            +2.0*c*(2.0*c - cs[i] - cs[j])
+            + (b0 - b0s[i])*(c - cs[j])
+            + (b0 - b0s[j])*(c - cs[i])
+            + 2.0*(c - cs[i])*(c - cs[j])
+            )
+            l[j] = v
+    return out
+
+def SRK_translated_d3epsilon_dninjnks(b0s, cs, b, c, epsilon, N, out=None):
+    if out is None:
+        out = [[[0.0]*N for _ in range(N)] for _ in range(N)]# numba: delete
+        # out = np.zeros((N, N, N)) # numba: uncomment
+
+    b0 = b + c
+    for i in range(N):
+        d3b_dnjnks = out[i]
+        for j in range(N):
+            row = d3b_dnjnks[j]
+            for k in range(N):
+                term = (-2.0*b0*(3.0*c - cs[i] - cs[j] - cs[k])
+                    - 2.0*c*(3.0*b0 - b0s[i] - b0s[j] - b0s[k])
+                    - 4.0*c*(3.0*c - cs[i] - cs[j] - cs[k])
+                    - (b0 - b0s[i])*(2.0*c - cs[j] - cs[k])
+                    - (b0 - b0s[j])*(2.0*c - cs[i] - cs[k])
+                    - (b0 - b0s[k])*(2.0*c - cs[i] - cs[j])
+                    - (c - cs[i])*(2.0*b0 - b0s[j] - b0s[k])
+                    - (c - cs[j])*(2.0*b0 - b0s[i] - b0s[k])
+                    - (c - cs[k])*(2.0*b0 - b0s[i] - b0s[j])
+                    - 2.0*(c - cs[i])*(2.0*c - cs[j] - cs[k])
+                    - 2.0*(c - cs[j])*(2.0*c - cs[i] - cs[k])
+                    - 2.0*(c - cs[k])*(2.0*c - cs[i] - cs[j])
+                    )
+                row[k] = term
+    return out
+
+def PR_translated_depsilon_dzs(epsilon, c, b, b0s, cs, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    b0 = b + c
+    b0_2 = b0*2.0
+    x0 = (b0_2 + 2.0*c)
+    x1 = c*2.0 - b0_2
+    for i in range(N):
+        out[i] = cs[i]*x0 + x1*b0s[i]
+    return out
+
+def PR_translated_depsilon_dns(epsilon, c, b, b0s, cs, N, out=None):
+    if out is None:
+        out = [0.0]*N
+    b0 = b + c
+    x0 = 2.0*b0*b0 - 4.0*b0*c - 2.0*c*c 
+    x1 = -2.0*b0 + 2.0*c
+    x2 = (2.0*b0 + 2.0*c)
+    for i in range(N):
+        out[i] = x0 + b0s[i]*x1 + cs[i]*x2
+    return out
+
+def PR_translated_d2delta_dninjs(b0s, cs, b, c, delta, N, out=None):
+    if out is None:
+        out = [[0.0]*N for _ in range(N)] # numba: delete
+        # out = np.zeros((N, N)) # numba: uncomment
+
+    b0 = b + c
+    for i in range(N):
+        t = delta - b0s[i] - cs[i]
+        r = out[i]
+        for j in range(N):
+            r[j] = 2.0*(t - b0s[j] - cs[j])
+    return out
+
+def PR_translated_d3delta_dninjnks(b0s, cs, delta, N, out=None):
+    if out is None:
+        out = [[[0.0]*N for _ in range(N)] for _ in range(N)]# numba: delete
+        # out = np.zeros((N, N, N)) # numba: uncomment
+
+    delta_six = 6.0*delta
+    for i in range(N):
+        b0ici = b0s[i] + cs[i]
+        d3b_dnjnks = out[i]
+        for j in range(N):
+            b0jcj = b0s[j] + cs[j]
+            r = d3b_dnjnks[j]
+            v0 = 4.0*(b0ici + b0jcj) - delta_six
+            for k in range(N):
+                r[k] = v0 + 4.0*(b0s[k] + cs[k])
+    return out
+
+
+def PR_translated_d3epsilon_dninjnks(b0s, cs, b, c, epsilon, N, out=None):
+    if out is None:
+        out = [[[0.0]*N for _ in range(N)] for _ in range(N)]# numba: delete
+        # out = np.zeros((N, N, N)) # numba: uncomment
+
+    b0 = b + c
+    for i in range(N):
+        d3b_dnjnks = out[i]
+        for j in range(N):
+            row = d3b_dnjnks[j]
+            for k in range(N):
+                term = (4.0*b0*(3.0*b0 - b0s[i] - b0s[j] - b0s[k])
+                -2.0*c*(6.0*b0 + 3.0*c - 2.0*(b0s[i] + b0s[j] + b0s[k]) -(cs[i] + cs[j] + cs[k]))
+
+                + 2.0*(b0 - b0s[i])*(2.0*b0 - b0s[j] - b0s[k])
+                + 2.0*(b0 - b0s[j])*(2.0*b0 - b0s[i] - b0s[k])
+                + 2.0*(b0 - b0s[k])*(2.0*b0 - b0s[i] - b0s[j])
+
+                - (c - cs[i])*(4.0*b0 - 2.0*b0s[j] - 2.0*b0s[k] + 2.0*c - cs[j] - cs[k])
+                - (c - cs[j])*(4.0*b0 - 2.0*b0s[i] - 2.0*b0s[k] + 2.0*c - cs[i] - cs[k])
+                - (c - cs[k])*(4.0*b0 - 2.0*b0s[i] - 2.0*b0s[j] + 2.0*c - cs[i] - cs[j])
+
+                - 2.0*(c + 2.0*b0)*(3.0*c - cs[i] - cs[j] - cs[k])
+
+                - (2.0*c - cs[i] - cs[j])*(2.0*b0 + c - 2.0*b0s[k] - cs[k])
+                - (2.0*c - cs[i] - cs[k])*(2.0*b0 + c - 2.0*b0s[j] - cs[j])
+                - (2.0*c - cs[j] - cs[k])*(2.0*b0 + c - 2.0*b0s[i] - cs[i])
+
+                )
+                row[k] = term
+    return out
+
+
+
+
+
+def PR_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_j_rows, N, lnphis=None):
+    if lnphis is None:
+        lnphis = [0.0]*N
     T_inv = 1.0/T
     P_T = P*T_inv
 
@@ -827,13 +1286,32 @@ def PR_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_j_rows, N, out=None):
     t50 = (x4 + x4)/(a_alpha*two_root_two_B)
     t51 = (x4 + (Z - 1.0)*two_root_two_B)/(b*two_root_two_B)
     for i in range(N):
-        out[i] = bs[i]*t51 - x0 - t50*a_alpha_j_rows[i]
-    return out
+        lnphis[i] = bs[i]*t51 - x0 - t50*a_alpha_j_rows[i]
+    return lnphis
 
-def VDW_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_roots, out=None):
-    N = len(bs)
-    if out is None:
-        out = [0.0]*N
+def SRK_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_j_rows, N, lnphis=None):
+    if lnphis is None:
+        lnphis = [0.0]*N
+    RT = T*R
+    P_RT = P/RT
+    A = a_alpha*P/(RT*RT)
+    B = b*P/RT
+    B_inv = 1.0/B
+    A_B = A*B_inv
+    t0 = log(Z - B)
+    t3 = log(1. + B/Z)
+    Z_minus_one_over_B = (Z - 1.0)*B_inv
+    two_over_a_alpha = 2./a_alpha
+    x0 = A_B*B_inv*t3
+    x1 = A_B*two_over_a_alpha*t3
+    x2 = (Z_minus_one_over_B + x0)*P_RT
+    for i in range(N):
+        lnphis[i] = bs[i]*x2 - t0 - x1*a_alpha_j_rows[i]
+    return lnphis
+
+def VDW_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_roots, N, lnphis=None):
+    if lnphis is None:
+        lnphis = [0.0]*N
     V = Z*R*T/P
 
     sqrt_a_alpha = sqrt(a_alpha)
@@ -841,40 +1319,136 @@ def VDW_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_roots, out=None):
     t2 = 2.0*sqrt_a_alpha/(R*T*V)
     t3 = 1.0/(V - b)
     for i in range(N):
-        out[i] = (bs[i]*t3 - t1 - t2*a_alpha_roots[i])
-    return out
+        lnphis[i] = (bs[i]*t3 - t1 - t2*a_alpha_roots[i])
+    return lnphis
 
-def lnphis_direct(zs, model, T, P, *args):
-    if model == 10200:
-        return PR_lnphis_fastest(zs, T, P, *args)
-    return PR_lnphis_fastest(zs, T, P, *args)
+def eos_mix_lnphis_general(T, P, Z, b, delta, epsilon, a_alpha, bs,
+                           a_alpha_roots, N, db_dns, da_alpha_dns, ddelta_dns, 
+                           depsilon_dns, lnphis=None):
+    if lnphis is None:
+        lnphis = [0.0]*N
+    V = Z*R*T/P
+    dV_dns = eos_mix_dV_dzs(T, P, Z, b, delta, epsilon, 
+                            a_alpha, db_dns, ddelta_dns,
+                            depsilon_dns, da_alpha_dns, N)
 
-def PR_lnphis_fastest(zs, T, P, kijs, l, g, bs, a_alphas, a_alpha_roots):
-    # Uses precomputed values
-    # Only creates its own arrays for a_alpha_j_rows and PR_lnphis
-    N = len(bs)
+    dlnphi_dns = G_dep_lnphi_d_helper(T, P, b, delta, epsilon, a_alpha, N,
+                                      Z, db_dns, depsilon_dns, ddelta_dns, dV_dns,
+                                      da_alpha_dns, G=False)
+
+    lnphi = eos_lnphi(T, P, V, b, delta, epsilon, a_alpha)
+    for i in range(N):
+        lnphis[i] = lnphi + dlnphi_dns[i]
+    return lnphis    
+
+
+
+
+
+def PR_lnphis_fastest(zs, T, P, N, kijs, l, g, bs, a_alphas, a_alpha_roots, a_alpha_j_rows=None, vec0=None,
+                      lnphis=None):
     b = 0.0
     for i in range(N):
         b += bs[i]*zs[i]
     delta = 2.0*b
     epsilon = -b*b
+    
+    Z, a_alpha, a_alpha_j_rows = eos_mix_a_alpha_volume(g, T, P, zs, kijs, b, delta, epsilon, a_alphas, a_alpha_roots,
+                                                        a_alpha_j_rows=a_alpha_j_rows, vec0=vec0)
+    return PR_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_j_rows, N, lnphis=lnphis)
+
+
+def SRK_lnphis_fastest(zs, T, P, N, kijs, l, g, bs, a_alphas, a_alpha_roots, a_alpha_j_rows=None, vec0=None,
+                      lnphis=None):
+    b = 0.0
+    for i in range(N):
+        b += bs[i]*zs[i]
+    delta = b
+    epsilon = 0.0
+    
+    Z, a_alpha, a_alpha_j_rows = eos_mix_a_alpha_volume(g, T, P, zs, kijs, b, delta, epsilon, a_alphas, a_alpha_roots,
+                                                        a_alpha_j_rows=a_alpha_j_rows, vec0=vec0)
+    return SRK_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_j_rows, N, lnphis=lnphis)
+
+
+def VDW_lnphis_fastest(zs, T, P, N, kijs, l, g, bs, a_alphas, a_alpha_roots, a_alpha_j_rows=None, vec0=None,
+                      lnphis=None):
+    b = 0.0
+    for i in range(N):
+        b += bs[i]*zs[i]
+    delta = 0.0
+    epsilon = 0.0
+    
+    Z, a_alpha, a_alpha_j_rows = eos_mix_a_alpha_volume(g, T, P, zs, kijs, b, delta, epsilon, a_alphas, a_alpha_roots,
+                                                        a_alpha_j_rows=a_alpha_j_rows, vec0=vec0)
+    return VDW_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_roots, N, lnphis=lnphis)
+
+
+def RK_lnphis_fastest(zs, T, P, N, kijs, l, g, bs, a_alphas, a_alpha_roots, a_alpha_j_rows=None, vec0=None,
+                      lnphis=None):
+    b = 0.0
+    for i in range(N):
+        b += bs[i]*zs[i]
+    delta = b
+    epsilon = 0.0
+    
+    Z, a_alpha, a_alpha_j_rows = eos_mix_a_alpha_volume(g, T, P, zs, kijs, b, delta, epsilon, a_alphas, a_alpha_roots,
+                                                        a_alpha_j_rows=a_alpha_j_rows, vec0=vec0)
+    
+    ddelta_dns = db_dns = eos_mix_db_dns(b, bs, N, out=None)
+    da_alpha_dns = eos_mix_da_alpha_dns(a_alpha, a_alpha_j_rows, N, out=None)
+    depsilon_dns = [0.0]*N
+
+    
+    return eos_mix_lnphis_general(T, P, Z, b, delta, epsilon, a_alpha, bs,
+                           a_alpha_roots, N, db_dns, da_alpha_dns, ddelta_dns, 
+                           depsilon_dns, lnphis=lnphis)
+
+
+def PR_translated_lnphis_fastest(zs, T, P, N, kijs, l, g, b0s, bs, cs, a_alphas, a_alpha_roots, a_alpha_j_rows=None, vec0=None,
+                      lnphis=None):
+    b0, c = 0.0, 0.0
+    for i in range(N):
+        b0 += b0s[i]*zs[i]
+        c += cs[i]*zs[i]
+        
+    b = b0 - c
+    delta = 2.0*(c + b0)
+    epsilon = -b0*b0 + c*(c + b0 + b0)
+    Z, a_alpha, a_alpha_j_rows = eos_mix_a_alpha_volume(g, T, P, zs, kijs, b, delta, epsilon, a_alphas, a_alpha_roots,
+                                                        a_alpha_j_rows=a_alpha_j_rows, vec0=vec0)
+    
+    db_dns = eos_mix_db_dns(b, bs, N, out=None)
+    da_alpha_dns = eos_mix_da_alpha_dns(a_alpha, a_alpha_j_rows, N, out=None)
+    depsilon_dns = PR_translated_depsilon_dns(epsilon, c, b, b0s, cs, N, out=None)
+    ddelta_dns = PR_translated_ddelta_dns(b0s, cs, delta, N, out=None)
+
+    
+    return eos_mix_lnphis_general(T, P, Z, b, delta, epsilon, a_alpha, bs,
+                           a_alpha_roots, N, db_dns, da_alpha_dns, ddelta_dns, 
+                           depsilon_dns, lnphis=lnphis)
+
+
+def SRK_translated_lnphis_fastest(zs, T, P, N, kijs, l, g, b0s, bs, cs, a_alphas, a_alpha_roots, a_alpha_j_rows=None, vec0=None,
+                      lnphis=None):
+    b0, c = 0.0, 0.0
+    for i in range(N):
+        b0 += b0s[i]*zs[i]
+        c += cs[i]*zs[i]
+        
+    b = b0 - c
+    delta =  c + c + b0
+    epsilon = c*(b0 + c)
+    Z, a_alpha, a_alpha_j_rows = eos_mix_a_alpha_volume(g, T, P, zs, kijs, b, delta, epsilon, a_alphas, a_alpha_roots,
+                                                        a_alpha_j_rows=a_alpha_j_rows, vec0=vec0)
+    
+    db_dns = eos_mix_db_dns(b, bs, N, out=None)
+    da_alpha_dns = eos_mix_da_alpha_dns(a_alpha, a_alpha_j_rows, N, out=None)
+    depsilon_dns = SRK_translated_depsilon_dns(b0s, cs, b, c, N, out=None)
+    ddelta_dns = SRK_translated_ddelta_dns(b0s, cs, delta, N, out=None)
+
+    
+    return eos_mix_lnphis_general(T, P, Z, b, delta, epsilon, a_alpha, bs,
+                           a_alpha_roots, N, db_dns, da_alpha_dns, ddelta_dns, 
+                           depsilon_dns, lnphis=lnphis)
 
-    a_alpha, a_alpha_j_rows = a_alpha_quadratic_terms(a_alphas, a_alpha_roots, T, zs, kijs)
-    V0, V1, V2 = volume_solutions_halley(T, P, b, delta, epsilon, a_alpha)
-    if l:
-        # Prefer liquid, ensure V0 is the smalest root
-        if V1 != 0.0:
-            if V0 > V1 and V1 > b:
-                V0 = V1
-            if V0 > V2 and V2 > b:
-                V0 = V2
-    elif g:
-        if V1 != 0.0:
-            if V0 < V1 and V1 > b:
-                V0 = V1
-            if V0 < V2 and V2 > b:
-                V0 = V2
-    else:
-        raise ValueError("Root must be specified")
-    Z = Z = P*V0/(R*T)
-    return PR_lnphis(T, P, Z, b, a_alpha, bs, a_alpha_j_rows, N)
