@@ -129,7 +129,9 @@ from chemicals.volume import *
 from chemicals import volume
 from chemicals.virial import BVirial_Pitzer_Curl, BVirial_Abbott, BVirial_Tsonopoulos, BVirial_Tsonopoulos_extended
 from chemicals import miscdata
-from chemicals.miscdata import lookup_VDI_tabular_data
+from chemicals.miscdata import lookup_VDI_tabular_data, COMMON_CHEMISTRY
+from chemicals.identifiers import CAS_to_int
+
 from thermo import electrochem
 from thermo.electrochem import Laliberte_density
 from thermo.coolprop import has_CoolProp, PropsSI, PhaseSI, coolprop_fluids, coolprop_dict, CoolProp_T_dependent_property
@@ -181,7 +183,7 @@ CRC_INORG_L_CONST = 'CRC_INORG_L_CONST'
 
 volume_liquid_methods = [DIPPR_PERRY_8E, VDI_PPDS, COOLPROP, MMSNM0FIT, VDI_TABULAR,
                          HTCOSTALDFIT, RACKETTFIT, CRC_INORG_L,
-                         CRC_INORG_L_CONST, MMSNM0, HTCOSTALD,
+                         CRC_INORG_L_CONST, COMMON_CHEMISTRY, MMSNM0, HTCOSTALD,
                          YEN_WOODS_SAT, RACKETT, YAMADA_GUNN,
                          BHIRUD_NORMAL, TOWNSEND_HALES, CAMPBELL_THODOS, EOS]
 '''Holds all low-pressure methods available for the :obj:`VolumeLiquid` class, for use
@@ -236,12 +238,6 @@ class VolumeLiquid(TPDependentProperty):
         None to not extrapolate; see
         :obj:`TDependentProperty <thermo.utils.TDependentProperty>`
         for a full list of all options, [-]
-    poly_fit : tuple(float, float, list[float]), optional
-        Tuple of (Tmin, Tmax, coeffs) representing a prefered fit to the
-        volume of the compound; the coefficients are evaluated with
-        horner's method, and the input variable and output are transformed by
-        the default transformations of this object; used instead of any other
-        default method if provided. [-]
     method : str or None, optional
         If specified, use this method by default and do not use the ranked
         sorting; an exception is raised if this is not a valid method for the
@@ -378,7 +374,7 @@ class VolumeLiquid(TPDependentProperty):
 
     ranked_methods = [DIPPR_PERRY_8E, VDI_PPDS, COOLPROP, MMSNM0FIT, VDI_TABULAR,
                       HTCOSTALDFIT, RACKETTFIT, CRC_INORG_L,
-                      CRC_INORG_L_CONST, MMSNM0, HTCOSTALD,
+                      CRC_INORG_L_CONST, COMMON_CHEMISTRY, MMSNM0, HTCOSTALD,
                       YEN_WOODS_SAT, RACKETT, YAMADA_GUNN,
                       BHIRUD_NORMAL, TOWNSEND_HALES, CAMPBELL_THODOS, EOS]
     '''Default rankings of the low-pressure methods.'''
@@ -556,14 +552,7 @@ class VolumeLiquid(TPDependentProperty):
         Vm : float
             Molar volume of the liquid at T and a low pressure, [m^3/mol]
         '''
-        if method == POLY_FIT:
-            if T < self.poly_fit_Tmin:
-                Vm = (T - self.poly_fit_Tmin)*self.poly_fit_Tmin_slope + self.poly_fit_Tmin_value
-            elif T > self.poly_fit_Tmax:
-                Vm = (T - self.poly_fit_Tmax)*self.poly_fit_Tmax_slope + self.poly_fit_Tmax_value
-            else:
-                Vm = horner(self.poly_fit_coeffs, T)
-        elif method == RACKETT:
+        if method == RACKETT:
             Vm = Rackett(T, self.Tc, self.Pc, self.Zc)
         elif method == YAMADA_GUNN:
             Vm = Yamada_Gunn(T, self.Tc, self.Pc, self.omega)
@@ -839,7 +828,7 @@ class VolumeSupercriticalLiquid(VolumeLiquid):
     '''
     def __init__(self, MW=None, Tc=None, Pc=None,
                  omega=None,  Psat=None, CASRN='', eos=None,
-                 poly_fit=None, extrapolation=None):
+                 extrapolation=None):
         self.CASRN = CASRN
         self.MW = MW
         self.Tc = Tc
@@ -873,8 +862,6 @@ class VolumeSupercriticalLiquid(VolumeLiquid):
         self.load_all_methods()
         self.extrapolation = extrapolation
 
-        if poly_fit is not None:
-            self._set_poly_fit(poly_fit)
 
     def load_all_methods(self):
         r'''Method which picks out coefficients for the specified chemical
@@ -921,16 +908,7 @@ class VolumeSupercriticalLiquid(VolumeLiquid):
         Vm : float
             Molar volume of the liquid at T and a supercritical pressure, [m^3/mol]
         '''
-        if method == POLY_FIT:
-            if T < self.poly_fit_Tmin:
-                Vm = (T - self.poly_fit_Tmin)*self.poly_fit_Tmin_slope + self.poly_fit_Tmin_value
-            elif T > self.poly_fit_Tmax:
-                Vm = (T - self.poly_fit_Tmax)*self.poly_fit_Tmax_slope + self.poly_fit_Tmax_value
-            else:
-                Vm = horner(self.poly_fit_coeffs, T)
-        else:
-            return self._base_calculate(T, method)
-        return Vm
+        return self._base_calculate(T, method)
 
     def calculate_P(self, T, P, method):
         r'''Method to calculate pressure-dependent liquid molar volume at
@@ -1327,12 +1305,6 @@ class VolumeGas(TPDependentProperty):
         None to not extrapolate; see
         :obj:`TDependentProperty <thermo.utils.TDependentProperty>`
         for a full list of all options, [-]
-    poly_fit : tuple(float, float, list[float]), optional
-        Tuple of (Tmin, Tmax, coeffs) representing a prefered fit to the
-        volume of the compound; the coefficients are evaluated with
-        horner's method, and the input variable and output are transformed by
-        the default transformations of this object; used instead of any other
-        default low-pressure method if provided. [-]
     method : str or None, optional
         If specified, use this method by default and do not use the ranked
         sorting; an exception is raised if this is not a valid method for the
@@ -1579,8 +1551,6 @@ class VolumeGas(TPDependentProperty):
                 validity = False
         elif method == COOLPROP:
             validity = PhaseSI('T', T, 'P', P, self.CASRN) in ['gas', 'supercritical_gas', 'supercritical', 'supercritical_liquid']
-        elif method == POLY_FIT:
-            validity = True
         else:
             return super(VolumeGas, self).test_method_validity_P(T, P, method)
         return validity
@@ -1786,12 +1756,6 @@ class VolumeSolid(TDependentProperty):
         None to not extrapolate; see
         :obj:`TDependentProperty <thermo.utils.TDependentProperty>`
         for a full list of all options, [-]
-    poly_fit : tuple(float, float, list[float]), optional
-        Tuple of (Tmin, Tmax, coeffs) representing a prefered fit to the
-        volume of the compound; the coefficients are evaluated with
-        horner's method, and the input variable and output are transformed by
-        the default transformations of this object; used instead of any other
-        default method if provided. [-]
     method : str or None, optional
         If specified, use this method by default and do not use the ranked
         sorting; an exception is raised if this is not a valid method for the
@@ -1897,13 +1861,6 @@ class VolumeSolid(TDependentProperty):
             Vms = self.CRC_INORG_S_Vm
         elif method == GOODMAN:
             Vms = Goodman(T, self.Tt, self.Vml_Tt)
-        elif method == POLY_FIT:
-            if T < self.poly_fit_Tmin:
-                Vms = (T - self.poly_fit_Tmin)*self.poly_fit_Tmin_slope + self.poly_fit_Tmin_value
-            elif T > self.poly_fit_Tmax:
-                Vms = (T - self.poly_fit_Tmax)*self.poly_fit_Tmax_slope + self.poly_fit_Tmax_value
-            else:
-                Vms = horner(self.poly_fit_coeffs, T)
         else:
             return self._base_calculate(T, method)
         return Vms
